Skip to contents

Returns the integer schema version that this installation of shinyplanr expects. Use this in your `3_setup_app.R` script to stamp the config with the correct version so that `load_config()` can detect mismatches.

Usage

get_schema_version()

Value

An integer scalar.

Examples

shinyplanr::get_schema_version()
#> [1] 2